@@ -79,12 +79,17 @@ func New() *Config {
 	return c
 }
 
-// NewNoWrites initializes a new config that does not allow writes. For use in tests.
+// NewInMemory initializes a new config that does not allow writes. For use in tests.
 // This does not migrate legacy option names to their correct config section.
-func NewNoWrites() *Config {
+func NewInMemory() *Config {
 	return newWithOptions(true)
 }
 
+// NewContextReadOnly returns a context with a read-only config.
+func NewContextInMemory() context.Context {
+	return NewInMemory().WithConfig(context.Background())
+}
+
 func newWithOptions(noWrites bool) *Config {
 	c := &Config{
 		cfgs: make(map[string]*gitconfig.Configs, 42),
