@@ -1,18 +1,18 @@
 package leaf
 
 import (
-	"context"
 	"testing"
 
 	"github.com/blang/semver/v4"
 	"github.com/gopasspw/gopass/internal/backend"
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/gopasspw/gopass/pkg/ctxutil"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
 func TestGit(t *testing.T) {
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	s, err := createSubStore(t)
 	require.NoError(t, err)
@@ -36,7 +36,7 @@ func TestGit(t *testing.T) {
 }
 
 func TestGitRevisions(t *testing.T) {
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	s, err := createSubStore(t)
 	require.NoError(t, err)
